@@ -249,10 +249,13 @@ class Worker:
     def __init__(self, worker_name: str, 
         create_if_not_exist=True, 
         segment_limit=200, 
-        connection_string=os.environ['AzureWebJobsStorage'], 
+        connection_string=None, 
         return_only_source=True
     ):
-        self.connection_string = connection_string
+        if connection_string is None:
+            self.connection_string = os.environ['AzureWebJobsStorage']
+        else:
+            self.connection_string = connection_string
         self.worker_name = worker_name
         self.segment_limit = segment_limit
 
